@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: devicemanager.cpp 678 2008-06-03 13:26:54Z dmurdoch $
+// $Id: devicemanager.cpp 947 2013-07-18 00:36:47Z murdoch $
 
 #include "DeviceManager.hpp"
 #include "types.h"
@@ -31,9 +31,9 @@ DeviceManager::~DeviceManager()
   }
 }
 
-bool DeviceManager::openDevice() 
+bool DeviceManager::openDevice(bool useNULL) 
 {
-  Device* pDevice = new Device(newID);  
+  Device* pDevice = new Device(newID, useNULL);  
   if ( pDevice->open() ) {
     ++newID;
     pDevice->addDisposeListener(this);
@@ -64,6 +64,15 @@ Device* DeviceManager::getAnyDevice()
   return pDevice;
 }
 
+Device* DeviceManager::getDevice(int id)
+{
+  for (Container::iterator i = devices.begin() ; i != devices.end() ; ++i ) {
+    if ( (*i)->getID() == id )
+      return *i;
+  }
+  return NULL;
+}
+
 bool DeviceManager::setCurrent(int id, bool silent)
 {
   char buffer[64];
@@ -95,6 +104,19 @@ int DeviceManager::getCurrent() {
     return 0;
 }
 
+int DeviceManager::getDeviceCount() {
+  int result = 0;
+  for (Container::iterator i = devices.begin(); i != devices.end() ; ++i, ++result);
+  return result;
+}
+
+void DeviceManager::getDeviceIds(int *buffer, int bufsize) {
+  int count = 0;
+  for (Container::iterator i = devices.begin(); i != devices.end() && count < bufsize; ++i, ++count) {
+    *(buffer++) = (*i)->getID();
+  }
+}
+
 /**
  * Device disposed handler
  **/
